@@ -275,7 +275,7 @@ class ValveModel(str, enum.Enum):
 class Valve(_Link):
     element_class: str = Field("Valve", const=True)
     model: ValveModel = Field(..., description="Specific type of valve")
-    coefficient: float = Field(..., ge=0.0, description="Energy loss coefficient")
+    coefficient: float = Field(..., ge=0.0, description="Discharge coefficient")
     diameter: float = Field(
         ..., ge=0.0, description="Measured characteristic internal diameter"
     )
@@ -293,7 +293,7 @@ class WeirModel(str, enum.Enum):
 class Weir(_Link):
     element_class: str = Field("Weir", const=True)
     model: WeirModel = Field(..., description="Specific type of weir")
-    coefficient: float = Field(..., gt=0.0, description="Energy loss coefficient")
+    coefficient: float = Field(..., gt=0.0, description="Discharge coefficient")
     min_crest_level: float
     max_crest_level: float
     crest_width: float = Field(..., gt=0.0)
@@ -308,5 +308,6 @@ class OrificeModel(str, enum.Enum):
 class Orifice(_Link):
     element_class: str = Field("Orifice", const=True)
     model: OrificeModel = Field(..., description="Specific type of orifice")
-    coefficient: float = Field(..., gt=0.0, description="Energy loss coefficient")
-    aperture: float = Field(..., ge=0.0, description="Characteristic width of opening")
+    coefficient: float = Field(..., gt=0.0, description="Discharge coefficient")
+    min_aperture: float = Field(..., ge=0.0, description="Minimum aperture")
+    max_aperture: float = Field(..., ge=0.0, description="Maximum aperture")
