@@ -124,7 +124,8 @@ elements = [
         "target_uid": "storage",
         "model": "free",
         "coefficient": 1.0,
-        "aperture": 10.0,
+        "min_aperture": 0.0,
+        "max_aperture": 10.0,
         "display_name": "orifice",
         "element_class": "Orifice",
         "domain": "water",
